aboutsummaryrefslogtreecommitdiff
path: root/src/modules/navigator/datalinkloss_params.c
diff options
context:
space:
mode:
authorThomas Gubler <thomasgubler@gmail.com>2014-07-20 17:40:26 +0200
committerThomas Gubler <thomasgubler@gmail.com>2014-07-20 17:40:26 +0200
commit8739308999b410ac8e2a92cf3e5fa63c5e18f5ba (patch)
tree29d99341ffd84ddb0e2d9099486b51b9b1c50e31 /src/modules/navigator/datalinkloss_params.c
parentb5ef8fd2cd54d180b5debe362a4c1f07f64394af (diff)
downloadpx4-firmware-8739308999b410ac8e2a92cf3e5fa63c5e18f5ba.tar.gz
px4-firmware-8739308999b410ac8e2a92cf3e5fa63c5e18f5ba.tar.bz2
px4-firmware-8739308999b410ac8e2a92cf3e5fa63c5e18f5ba.zip
WIP, datalinkloss: implementing basic behavior
Diffstat (limited to 'src/modules/navigator/datalinkloss_params.c')
-rw-r--r--src/modules/navigator/datalinkloss_params.c91
1 files changed, 59 insertions, 32 deletions
diff --git a/src/modules/navigator/datalinkloss_params.c b/src/modules/navigator/datalinkloss_params.c
index bfe6ce7e1..a836fc8ca 100644
--- a/src/modules/navigator/datalinkloss_params.c
+++ b/src/modules/navigator/datalinkloss_params.c
@@ -32,11 +32,11 @@
****************************************************************************/
/**
- * @file rtl_params.c
+ * @file datalinkloss_params.c
*
* Parameters for RTL
*
- * @author Julian Oes <julian@oes.ch>
+ * @author Thomas Gubler <thomasgubler@gmail.com>
*/
#include <nuttx/config.h>
@@ -44,55 +44,82 @@
#include <systemlib/param/param.h>
/*
- * RTL parameters, accessible via MAVLink
+ * Data Link Loss parameters, accessible via MAVLink
*/
/**
- * Loiter radius after RTL (FW only)
+ * Comms hold wait time
*
- * Default value of loiter radius after RTL (fixedwing only).
+ * The amount of time in seconds the system should wait at the comms hold waypoint
*
- * @unit meters
+ * @unit seconds
* @min 0.0
- * @group RTL
+ * @group DLL
*/
-PARAM_DEFINE_FLOAT(RTL_LOITER_RAD, 50.0f);
+PARAM_DEFINE_FLOAT(NAV_DLL_CH_T, 120.0f);
/**
- * RTL altitude
+ * Comms hold Lat
*
- * Altitude to fly back in RTL in meters
+ * Latitude of comms hold waypoint
*
- * @unit meters
- * @min 0
- * @max 1
- * @group RTL
+ * @unit degrees * 1e7
+ * @min 0.0
+ * @group DLL
*/
-PARAM_DEFINE_FLOAT(RTL_RETURN_ALT, 100);
+PARAM_DEFINE_INT32(NAV_DLL_CH_LAT, 266072120);
+/**
+ * Comms hold Lon
+ *
+ * Longitude of comms hold waypoint
+ *
+ * @unit degrees * 1e7
+ * @min 0.0
+ * @group DLL
+ */
+PARAM_DEFINE_INT32(NAV_DLL_CH_LON, 1518453890);
/**
- * RTL loiter altitude
+ * Comms hold alt
*
- * Stay at this altitude above home position after RTL descending.
- * Land (i.e. slowly descend) from this altitude if autolanding allowed.
+ * Altitude of comms hold waypoint
*
- * @unit meters
- * @min 0
- * @max 100
- * @group RTL
+ * @unit m
+ * @min 0.0
+ * @group DLL
*/
-PARAM_DEFINE_FLOAT(RTL_DESCEND_ALT, 20);
+PARAM_DEFINE_FLOAT(NAV_DLL_CH_ALT, 600.0f);
/**
- * RTL delay
+ * Airfield home Lat
*
- * Delay after descend before landing in RTL mode.
- * If set to -1 the system will not land but loiter at NAV_LAND_ALT.
+ * Latitude of airfield home waypoint
*
- * @unit seconds
- * @min -1
- * @max
- * @group RTL
+ * @unit degrees * 1e7
+ * @min 0.0
+ * @group DLL
+ */
+PARAM_DEFINE_INT32(NAV_DLL_AH_LAT, 265847810);
+
+/**
+ * Airfield home Lon
+ *
+ * Longitude of airfield home waypoint
+ *
+ * @unit degrees * 1e7
+ * @min 0.0
+ * @group DLL
+ */
+PARAM_DEFINE_INT32(NAV_DLL_AH_LON, 1518423250);
+
+/**
+ * Airfield home alt
+ *
+ * Altitude of airfield home waypoint
+ *
+ * @unit m
+ * @min 0.0
+ * @group DLL
*/
-PARAM_DEFINE_FLOAT(RTL_LAND_DELAY, -1.0f);
+PARAM_DEFINE_FLOAT(NAV_DLL_AH_ALT, 600.0f);
@@ -32,11 +32,11 @@
*
- * Parameters for RTL
+ * Parameters for DLL
*